"use strict";
exports.__esModule = true;
exports.addDiacriticToSyllable = exports.stringifyPinyinSyllable = exports.stringifyPinyinString = void 0;
exports.stringifyPinyinString = function (pinyinStringSegments) {
    return pinyinStringSegments
        .map(function (pinyinStringSegment) {
        switch (pinyinStringSegment.type) {
            case 'TEXT':
                return pinyinStringSegment.text;
            case 'PINYIN_SYLLABLE':
                return exports.stringifyPinyinSyllable(pinyinStringSegment);
        }
    })
        .join('');
}; // TODO(jan): Maybe add this "\u{200B}"
exports.stringifyPinyinSyllable = function (pinyinSyllable) {
    var out = '';
    if (pinyinSyllable.initial === undefined) {
        out = '-';
    }
    else {
        out += pinyinSyllable.initial;
        if (pinyinSyllable.isCapitalized) {
            out = out[0].toLocaleUpperCase() + out.slice(1);
        }
        if (pinyinSyllable.final === undefined) {
            out += '-';
        }
        else {
            out += pinyinSyllable.final;
            if (pinyinSyllable.erhua) {
                out += 'r';
            }
            if (pinyinSyllable.tone !== undefined) {
                out = exports.addDiacriticToSyllable(out, pinyinSyllable.tone);
            }
        }
    }
    return out;
};
var VOWELS = ['A', 'O', 'a', 'o', 'e', 'iu', 'i', 'u', 'ü'];
var ALL_TONE_MARKS = [
    ['Ā', 'Ō', 'ā', 'ō', 'ē', 'iū', 'ī', 'ū', 'ǖ'],
    ['Á', 'Ó', 'á', 'ó', 'é', 'iú', 'í', 'ú', 'ǘ'],
    ['Ǎ', 'Ǒ', 'ǎ', 'ǒ', 'ě', 'iǔ', 'ǐ', 'ǔ', 'ǚ'],
    ['À', 'Ò', 'à', 'ò', 'è', 'iù', 'ì', 'ù', 'ǜ'],
];
exports.addDiacriticToSyllable = function (syllable, tone) {
    if (tone === 5)
        return syllable;
    var toneMarks = ALL_TONE_MARKS[tone - 1];
    for (var i = 0; i < VOWELS.length; i++) {
        var vowel = VOWELS[i];
        var newSyllable = syllable.replace(vowel, toneMarks[i]);
        if (newSyllable !== syllable) {
            return newSyllable;
        }
    }
    return syllable;
};
