"use strict";
exports.__esModule = true;
var stringify_1 = require("./stringify");
describe('addDiacriticToSyllable', function () {
    test('empty syllable', function () {
        expect(stringify_1.addDiacriticToSyllable('', 1)).toMatchSnapshot();
    });
    test('simple syllable', function () {
        expect(stringify_1.addDiacriticToSyllable('zhi', 1)).toMatchSnapshot();
    });
    test('non existent syllable', function () {
        expect(stringify_1.addDiacriticToSyllable('piu', 2)).toMatchSnapshot();
    });
    test('erhua', function () {
        expect(stringify_1.addDiacriticToSyllable('huar', 3)).toMatchSnapshot();
    });
    test('syllable with whitespace', function () {
        expect(stringify_1.addDiacriticToSyllable('dao ', 4)).toMatchSnapshot();
    });
    test('neutral tone', function () {
        expect(stringify_1.addDiacriticToSyllable('ma', 5)).toMatchSnapshot();
    });
});
describe('stringifyPinyinSyllable', function () {
    test('type only', function () {
        expect(stringify_1.stringifyPinyinSyllable({
            type: 'PINYIN_SYLLABLE'
        })).toMatchSnapshot();
    });
    test('initial only', function () {
        expect(stringify_1.stringifyPinyinSyllable({
            type: 'PINYIN_SYLLABLE',
            initial: 'z'
        })).toMatchSnapshot();
    });
    test(' capitalization only', function () {
        expect(stringify_1.stringifyPinyinSyllable({
            type: 'PINYIN_SYLLABLE',
            isCapitalized: true
        })).toMatchSnapshot();
    });
    test('initial and capitalization only', function () {
        expect(stringify_1.stringifyPinyinSyllable({
            type: 'PINYIN_SYLLABLE',
            initial: 'ch',
            isCapitalized: true
        })).toMatchSnapshot();
    });
    test('initial and final only', function () {
        expect(stringify_1.stringifyPinyinSyllable({
            type: 'PINYIN_SYLLABLE',
            initial: 'ch',
            final: 'uan'
        })).toMatchSnapshot();
    });
    test('erhua without final', function () {
        expect(stringify_1.stringifyPinyinSyllable({
            type: 'PINYIN_SYLLABLE',
            initial: 'r',
            erhua: true
        })).toMatchSnapshot();
    });
    test('erhua with final', function () {
        expect(stringify_1.stringifyPinyinSyllable({
            type: 'PINYIN_SYLLABLE',
            initial: 'r',
            final: 'uo',
            erhua: true
        })).toMatchSnapshot();
    });
    test('empty string final', function () {
        expect(stringify_1.stringifyPinyinSyllable({
            type: 'PINYIN_SYLLABLE',
            initial: 'a',
            final: ''
        })).toMatchSnapshot();
    });
    test('empty string final with erhua', function () {
        expect(stringify_1.stringifyPinyinSyllable({
            type: 'PINYIN_SYLLABLE',
            initial: 'a',
            final: '',
            erhua: true
        })).toMatchSnapshot();
    });
    test('tone', function () {
        expect(stringify_1.stringifyPinyinSyllable({
            type: 'PINYIN_SYLLABLE',
            initial: 'a',
            final: '',
            tone: 1
        })).toMatchSnapshot();
    });
    test('neutral tone', function () {
        expect(stringify_1.stringifyPinyinSyllable({
            type: 'PINYIN_SYLLABLE',
            initial: 'm',
            final: 'a',
            tone: 5
        })).toMatchSnapshot();
    });
    test('tone and erhua', function () {
        expect(stringify_1.stringifyPinyinSyllable({
            type: 'PINYIN_SYLLABLE',
            initial: 'h',
            final: 'ua',
            tone: 1,
            erhua: true
        })).toMatchSnapshot();
    });
});
